# -*- coding: utf-8 -*-
__author__ = "Paul Schifferer <dm@sweetrpg.com>"
"""Exceptions.
"""


class UnknownDataType(Exception):
    pass


class NotFound(Exception):
    pass


class UnexpectedResponse(Exception):
    pass


class InvalidResponseData(Exception):
    pass
